@@ -3,6 +3,7 @@
 class Module # :nodoc:
   def mattr_reader(*syms)
     syms.each do |sym|
+      next if sym.is_a?(Hash)
       class_eval(<<-EOS, __FILE__, __LINE__)
         unless defined? @@#{sym}
           @@#{sym} = nil
@@ -20,6 +21,7 @@ class Module # :nodoc:
   end
   
   def mattr_writer(*syms)
+    options = syms.last.is_a?(Hash) ? syms.pop : {}
     syms.each do |sym|
       class_eval(<<-EOS, __FILE__, __LINE__)
         unless defined? @@#{sym}
@@ -29,10 +31,12 @@ class Module # :nodoc:
         def self.#{sym}=(obj)
           @@#{sym} = obj
         end
-
+        
+        #{"
         def #{sym}=(obj)
           @@#{sym} = obj
         end
+        " unless options[:instance_writer] == false }
       EOS
     end
   end
